@@ -1,11 +1,15 @@
 #' @describeIn plot Plots a two-dimensional confidence region for model
 #'   parameters.
 #' @importFrom graphics points polygon plot.default text
+#' @srrstats {RE6.0} `plot` method is available for an `ConfregEL` object that
+#'   is returned by the `confreg()` method.
 setMethod("plot", "ConfregEL", function(x, ...) {
   args <- list(...)
   if (!exists("main", args)) {
-    args$main <- paste(if (!is.na(x@level)) sprintf("%0.1f%%", 100 * x@level),
-                       "Confidence Region")
+    args$main <- paste(
+      if (!is.na(x@level)) sprintf("%0.1f%%", 100 * x@level),
+      "Confidence Region"
+    )
   }
   if (!exists("xlab", args)) {
     args$xlab <- x@pnames[1L]
@@ -30,6 +34,8 @@ setMethod("plot", "ConfregEL", function(x, ...) {
 #' @describeIn plot Plots empirical likelihood displacement values versus
 #'   observation index.
 #' @importFrom graphics polygon plot.default
+#' @srrstats {RE6.0} `plot` method is available for an `ELD` object that is
+#'   returned by the `eld()` method.
 setMethod("plot", "ELD", function(x, ...) {
   args <- list(...)
   if (!exists("xlab", args)) {
